@@ -36,8 +36,7 @@ class Common(object):
                                                     env_value[LcConst.BACK_END_API_URI])
         self.workspace_alarm = Alarm()
 
-        self.notebook_info = None
-        self.set_current_notebook()
+        self.notebook_info = get_current_notebook()
 
     def set_storage(self,
                     access_key=None,  # aws-s3
