@@ -19,7 +19,7 @@ from Accuinsight.modeler.core.get_for_visual import roc_pr_curve, get_true_y, ge
 from Accuinsight.modeler.clients.modeler_api import LifecycleRestApi
 from Accuinsight.modeler.utils.dependency.dependencies import gather_sources_and_dependencies
 from Accuinsight.modeler.utils.dl_utils import delete_files_except_best, get_best_model_path
-from Accuinsight.modeler.utils.os_getenv import is_in_ipython, get_current_notebook, get_os_env
+from Accuinsight.modeler.utils.os_getenv import is_in_ipython, get_os_env
 from Accuinsight.modeler.core.feature_contribution import shap_value
 from Accuinsight.Lifecycle.common import Common
 
@@ -71,7 +71,7 @@ class accuinsight(Common):
         run_id = None
 
         if is_in_ipython():
-            var_model_file_path = get_current_notebook()
+            var_model_file_path = self.notebook_info
             _caller_globals = inspect.stack()[1][0].f_globals
             (
                 mainfile,
